@@ -1,20 +1,9 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
+/*
+    This file is part of the KDE project
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KJOBTRACKERINTERFACE_H
@@ -23,8 +12,8 @@
 #include <kcoreaddons_export.h>
 #include <kjob.h>
 
-#include <QtCore/QObject>
-#include <QtCore/QPair>
+#include <QObject>
+#include <QPair>
 
 /**
  * @class KJobTrackerInterface kjobtrackerinterface.h KJobTrackerInterface
@@ -41,7 +30,7 @@ public:
      *
      * @param parent the parent object
      */
-    KJobTrackerInterface(QObject *parent = nullptr);
+    explicit KJobTrackerInterface(QObject *parent = nullptr);
 
     /**
      * Destroys a KJobTrackerInterface
